package com.example.what_the_fantasy.ui.navigations

import androidx.compose.runtime.Composable
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import com.example.what_the_fantasy.ui.screens.AccueilPage
import com.example.what_the_fantasy.ui.screens.FavoritePage
import com.example.what_the_fantasy.ui.screens.LoginPage
import com.example.what_the_fantasy.ui.screens.ProfilPage
import com.example.what_the_fantasy.ui.screens.QuizPage
import com.example.what_the_fantasy.ui.screens.QuotePage
import com.example.what_the_fantasy.ui.screens.SearchPage
import com.example.what_the_fantasy.ui.screens.SignUpPage
import com.example.what_the_fantasy.ui.screens.SubmitQuotePage



sealed class Destination(val route: String) {
    data object Login : Destination("Login")
    data object Accueil : Destination("Accueil")
    data object Favorite : Destination("Favorite")
    data object Profil : Destination("Profil")
    data object Quiz : Destination("Quiz")
    data object Quote : Destination("Quote")
    data object Search : Destination("Search")
    data object SignUp : Destination("SignUp")
    data object SubmitQuote : Destination("SubmitQuote")
}

@Composable
fun AppNavigator() {
    val navController = rememberNavController()

    NavHost(navController, startDestination = Destination.Login.route) {
        composable(Destination.Login.route) {
            LoginPage(
                navControllerSignUp = { navController.navigate(Destination.SignUp.route) },
                navControllerProfil = { navController.navigate(Destination.Profil.route) }
            )
        }
        composable(Destination.Accueil.route) { AccueilPage() }
        composable(Destination.Favorite.route) { FavoritePage() }
        composable(Destination.Profil.route) { ProfilPage(navController) }
        composable(Destination.Quiz.route) { QuizPage() }
        composable(Destination.Quote.route) { QuotePage() }
        composable(Destination.Search.route) { SearchPage() }
        composable(Destination.SignUp.route) { SignUpPage(navController) }
        composable(Destination.SubmitQuote.route) { SubmitQuotePage() }
    }
}
